@@ -31,6 +31,19 @@
 extern PyObject* alpm_error;
 void init_pyalpm_error(PyObject* module);
 
+#define RET_ERR(msg, ret) do { \
+      Py_INCREF(Py_None); \
+      PyObject *error_obj = Py_BuildValue("(siO)", msg, pm_errno, Py_None); \
+      PyErr_SetObject(alpm_error, error_obj); \
+      return ret;                          \
+    } while(0)
+
+#define RET_ERR_DATA(msg, arg, ret) do { \
+      PyObject *error_obj = Py_BuildValue("(siN)", msg, pm_errno, arg); \
+      PyErr_SetObject(alpm_error, error_obj); \
+      return ret;                          \
+    } while(0)
+
 typedef PyObject *(pyobjectbuilder)(void*);
 PyObject* pyobject_from_string(void *s);
 
@@ -42,3 +55,5 @@ unsigned short check_init(void);
 void set_init(unsigned short i);
 
 #endif // _PY_ALPM_UTIL_H
+
+/* vim: set ts=2 sw=2 et: */
